@@ -46,7 +46,8 @@ GraphBitMapLen=0
 GraphBitMapHeight=0
 
 StatisticsBitMap=""
-StatisticsBitMapLen=110
+#StatisticsBitMapLen=110
+StatisticsBitMapLen=230
 StatisticsBitMapHeight=65
 
 DisplayIsOn=True
@@ -207,6 +208,9 @@ WakeUp_Song_Start_Volume=10
 SongIsPlaying=False
 Timer_MusicPlayer=0
 
-glib_loop=""
+#glib_loop=""
+
+#Error_Huck_installed=False
+
+
 
-Error_Huck_installed=False
